==> ui-18.1.4.tgz: package/components/pagination/Pagination.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx } from "react/jsx-runtime";
import { isNull } from 'lodash';
import React, { useEffect, useRef, useState } from 'react';
import { DoubleLeftOutlined, DoubleRightOutlined, EllipsisOutlined, LeftOutlined, RightOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { DInput } from '../input';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DSelect } from '../select';
import { getButtonRoleAttributes } from './utils';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DPagination' });
export function DPagination(props) {
    var _a, _b;
    const _c = useComponentConfig(COMPONENT_NAME, props), { dActive, dTotal, dPageSize, dPageSizeList = [10, 20, 50, 100], dCompose = ['pages'], dCustomRender, dMini = false, onPaginationChange } = _c, restProps = __rest(_c, ["dActive", "dTotal", "dPageSize", "dPageSizeList", "dCompose", "dCustomRender", "dMini", "onPaginationChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const navRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const [active, _changeActive] = useDValue(1, dActive);
    const changeActive = (_active) => {
        setIsChange(true);
        const newActive = Math.max(Math.min(_active, lastPage), 1);
        _changeActive(newActive);
        if (!Object.is(newActive, active)) {
            onPaginationChange === null || onPaginationChange === void 0 ? void 0 : onPaginationChange(newActive, pageSize);
        }
    };
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const [pageSize, _changePageSize] = useDValue((_a = dPageSizeList[0]) !== null && _a !== void 0 ? _a : 10, dPageSize);
    const changePageSize = (_pageSize) => {
        _changePageSize(_pageSize);
        const lastPage = Math.max(Math.ceil(dTotal / _pageSize), 1);
        const newActive = Math.max(Math.min(active, lastPage), 1);
        if (!Object.is(newActive, active) || !Object.is(_pageSize, pageSize)) {
            onPaginationChange === null || onPaginationChange === void 0 ? void 0 : onPaginationChange(newActive, _pageSize);
        }
    };
    const [jumpValue, setJumpValue] = useState('');
    const lastPage = Math.max(Math.ceil(dTotal / pageSize), 1);
    const totalNode = (() => {
        if (dCompose.includes('total')) {
            const range = [Math.min((active - 1) * pageSize + 1, dTotal), Math.min(active * pageSize, dTotal)];
            if (dCustomRender && dCustomRender.total) {
                return dCustomRender.total(range);
            }
            else {
                return (_jsxs("div", { children: [t('Pagination', 'Total'), " ", dTotal, " ", t('Pagination', 'items')] }));
            }
        }
        return null;
    })();
    const [prevNode, pageNode, nextNode] = (() => {
        let [prevNode, nextNode] = [null, null];
        if (dCompose.includes('pages')) {
            prevNode = (_jsx("li", Object.assign({}, getButtonRoleAttributes(() => {
                changeActive(active - 1);
            }, active === 1), { className: getClassName(`${dPrefix}pagination__button`, {
                    'is-disabled': active === 1,
                    [`${dPrefix}pagination__button--border`]: !(dCustomRender && dCustomRender.prev),
                }), title: t('Pagination', 'Previous page') }, { children: dCustomRender && dCustomRender.prev ? dCustomRender.prev : _jsx(LeftOutlined, {}) })));
            nextNode = (_jsx("li", Object.assign({}, getButtonRoleAttributes(() => {
                changeActive(active + 1);
            }, active === lastPage), { className: getClassName(`${dPrefix}pagination__button`, {
                    'is-disabled': active === lastPage,
                    [`${dPrefix}pagination__button--border`]: !(dCustomRender && dCustomRender.next),
                }), style: { marginRight: dCompose[dCompose.length - 1] === 'pages' ? 0 : `var(--${dPrefix}pagination-space)` }, title: t('Pagination', 'Next page') }, { children: dCustomRender && dCustomRender.next ? dCustomRender.next : _jsx(RightOutlined, {}) })));
        }
        return [
            prevNode,
            (page) => {
                if (dCustomRender && dCustomRender.page) {
                    return dCustomRender.page(page);
                }
                else {
                    return _jsx("div", { children: page });
                }
            },
            nextNode,
        ];
    })();
    const pageSizeNode = (() => {
        const list = dPageSizeList.map((size) => ({
            label: size.toString(),
            value: size,
        }));
        return (_jsx(DSelect, { className: `${dPrefix}pagination__page-size`, style: { marginRight: dCompose[dCompose.length - 1] === 'page-size' ? 0 : undefined }, dList: list, dModel: pageSize, dCustomItem: (item) => (dCustomRender && dCustomRender.pageSize ? dCustomRender.pageSize(item.value) : item.label), dCustomSelected: (select) => `${select.label}${t('Pagination', ' / Page')}`, onModelChange: (value) => {
                if (!isNull(value)) {
                    changePageSize(value);
                }
            } }, "page-size"));
    })();
    const jumpNode = (() => {
        if (dCompose.includes('jump')) {
            const jumpInput = (_jsx(DInput, { className: `${dPrefix}pagination__jump-input`, dType: "number", dMax: lastPage, dMin: 1, dStep: 1, dModel: jumpValue, dNumbetButton: !dMini, dInputRender: (el) => cloneHTMLElement(el, {
                    onKeyDown: (e) => {
                        var _a, _b;
                        (_b = (_a = el.props).onKeyDown) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                        if (e.code === 'Enter') {
                            e.preventDefault();
                            const val = Number(jumpValue);
                            if (!isNaN(val)) {
                                changeActive(val);
                            }
                        }
                    },
                }), onModelChange: setJumpValue }));
            if (dCustomRender && dCustomRender.jump) {
                return dCustomRender.jump(jumpInput);
            }
            else {
                return (_jsxs("div", Object.assign({ className: `${dPrefix}pagination__jump-wrapper` }, { children: [t('Pagination', 'Go'), " ", jumpInput, " ", t('Pagination', 'Page')] })));
            }
        }
        return null;
    })();
    return (_jsx("nav", Object.assign({}, restProps, { ref: navRef, className: getClassName(restProps.className, `${dPrefix}pagination`, {
            [`${dPrefix}pagination--mini`]: dMini,
            'is-change': isChange,
        }), role: "navigation", "aria-label": (_b = restProps['aria-label']) !== null && _b !== void 0 ? _b : 'Pagination Navigation' }, { children: dCompose.map((item) => {
            if (item === 'total') {
                return (_jsx("div", Object.assign({ className: `${dPrefix}pagination__total`, style: { marginRight: dCompose[dCompose.length - 1] === 'total' ? 0 : undefined } }, { children: totalNode }), "total"));
            }
            if (item === 'pages') {
                let pages = [];
                if (lastPage <= 7) {
                    pages = Array.from({ length: lastPage }).map((_, index) => index + 1);
                }
                else {
                    for (let n = -3; n <= 3; n++) {
                        pages.push(active + n);
                    }
                    if (pages[0] < 1) {
                        pages = pages.map((n) => n + (1 - pages[0]));
                    }
                    if (pages[6] > lastPage) {
                        pages = pages.map((n) => n - (pages[6] - lastPage));
                    }
                    if (pages[0] > 1) {
                        pages[0] = 1;
                        pages[1] = 'prev5';
                    }
                    if (pages[6] < lastPage) {
                        pages[6] = lastPage;
                        pages[5] = 'next5';
                    }
                }
                return (_jsxs(React.Fragment, { children: [prevNode, pages.map((n) => {
                            if (n === 'prev5') {
                                return (_createElement("li", Object.assign({}, getButtonRoleAttributes(() => {
                                    changeActive(active - 5);
                                }), { key: "prev5", className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--jump5`), title: t('Pagination', '5 pages forward') }),
                                    _jsx(DoubleLeftOutlined, { className: `${dPrefix}pagination__jump5-icon` }),
                                    _jsx("div", Object.assign({ className: `${dPrefix}pagination__ellipsis` }, { children: _jsx(EllipsisOutlined, {}) }))));
                            }
                            else if (n === 'next5') {
                                return (_createElement("li", Object.assign({}, getButtonRoleAttributes(() => {
                                    changeActive(active + 5);
                                }), { key: "next5", className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--jump5`), title: t('Pagination', '5 pages backward') }),
                                    _jsx(DoubleRightOutlined, { className: `${dPrefix}pagination__jump5-icon` }),
                                    _jsx("div", Object.assign({ className: `${dPrefix}pagination__ellipsis` }, { children: _jsx(EllipsisOutlined, {}) }))));
                            }
                            else {
                                return (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--border`, `${dPrefix}pagination__button--number`, {
                                        'is-active': active === n,
                                    }), tabIndex: 0, "data-number": n, onClick: () => {
                                        changeActive(n);
                                    }, onKeyDown: (e) => {
                                        const focusN = (num) => {
                                            if (navRef.current) {
                                                const activeEl = navRef.current.querySelector(`li[data-number="${num}"]`);
                                                activeEl === null || activeEl === void 0 ? void 0 : activeEl.focus({ preventScroll: true });
                                            }
                                            changeActive(num);
                                        };
                                        switch (e.code) {
                                            case 'ArrowLeft':
                                                e.preventDefault();
                                                focusN(n - 1);
                                                break;
                                            case 'ArrowRight':
                                                e.preventDefault();
                                                focusN(n + 1);
                                                break;
                                            case 'Home':
                                                e.preventDefault();
                                                focusN(1);
                                                break;
                                            case 'End':
                                                e.preventDefault();
                                                focusN(lastPage);
                                                break;
                                            default:
                                                break;
                                        }
                                    } }, { children: pageNode(n) }), n));
                            }
                        }), nextNode] }, "pages"));
            }
            if (item === 'page-size') {
                return pageSizeNode;
            }
            if (item === 'jump') {
                return (_jsx("div", Object.assign({ className: `${dPrefix}pagination__jump`, style: { marginRight: dCompose[dCompose.length - 1] === 'jump' ? 0 : undefined } }, { children: jumpNode }), "jump"));
            }
            return null;
        }) })));
}

==> ui-18.3.7.tgz: package/components/pagination/Pagination.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { createElement as _createElement } from "react";
import { jsxs as _jsxs, jsx as _jsx, Fragment as _Fragment } from "react/jsx-runtime";
import { isNull } from 'lodash';
import React, { useEffect, useRef, useState } from 'react';
import { DoubleLeftOutlined, DoubleRightOutlined, EllipsisOutlined, LeftOutlined, RightOutlined } from '@react-devui/icons';
import { getClassName } from '@react-devui/utils';
import { useDValue } from '../../hooks';
import { cloneHTMLElement, registerComponentMate } from '../../utils';
import { DInput } from '../input';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
import { DSelect } from '../select';
import { getButtonRoleAttributes } from './utils';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DPagination' });
export function DPagination(props) {
    var _a, _b;
    const _c = useComponentConfig(COMPONENT_NAME, props), { dActive, dTotal, dPageSize, dPageSizeList = [10, 20, 50, 100], dCompose = ['pages'], dCustomRender, dMini = false, onPaginationChange } = _c, restProps = __rest(_c, ["dActive", "dTotal", "dPageSize", "dPageSizeList", "dCompose", "dCustomRender", "dMini", "onPaginationChange"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    //#region Ref
    const navRef = useRef(null);
    //#endregion
    const [t] = useTranslation();
    const [active, _changeActive] = useDValue(1, dActive);
    const changeActive = (_active) => {
        setIsChange(true);
        const newActive = Math.max(Math.min(_active, lastPage), 1);
        _changeActive(newActive);
        if (!Object.is(newActive, active)) {
            onPaginationChange === null || onPaginationChange === void 0 ? void 0 : onPaginationChange(newActive, pageSize);
        }
    };
    const [isChange, setIsChange] = useState(false);
    // eslint-disable-next-line react-hooks/exhaustive-deps
    useEffect(() => {
        if (isChange) {
            setIsChange(false);
        }
    });
    const [pageSize, _changePageSize] = useDValue((_a = dPageSizeList[0]) !== null && _a !== void 0 ? _a : 10, dPageSize);
    const changePageSize = (_pageSize) => {
        _changePageSize(_pageSize);
        const lastPage = Math.max(Math.ceil(dTotal / _pageSize), 1);
        const newActive = Math.max(Math.min(active, lastPage), 1);
        if (!Object.is(newActive, active) || !Object.is(_pageSize, pageSize)) {
            onPaginationChange === null || onPaginationChange === void 0 ? void 0 : onPaginationChange(newActive, _pageSize);
        }
    };
    const [jumpValue, setJumpValue] = useState('');
    const lastPage = Math.max(Math.ceil(dTotal / pageSize), 1);
    const totalNode = (() => {
        if (dCompose.includes('total')) {
            const range = [Math.min((active - 1) * pageSize + 1, dTotal), Math.min(active * pageSize, dTotal)];
            if (dCustomRender && dCustomRender.total) {
                return dCustomRender.total(range);
            }
            else {
                return (_jsxs("div", { children: [t('Pagination', 'Total'), " ", dTotal, " ", t('Pagination', 'items')] }));
            }
        }
        return null;
    })();
    const [prevNode, pageNode, nextNode] = (() => {
        let [prevNode, nextNode] = [null, null];
        if (dCompose.includes('pages')) {
            prevNode = (_jsx("li", Object.assign({}, getButtonRoleAttributes(() => {
                changeActive(active - 1);
            }, active === 1), { className: getClassName(`${dPrefix}pagination__button`, {
                    'is-disabled': active === 1,
                    [`${dPrefix}pagination__button--border`]: !(dCustomRender && dCustomRender.prev),
                }), title: t('Pagination', 'Previous page') }, { children: dCustomRender && dCustomRender.prev ? dCustomRender.prev : _jsx(LeftOutlined, {}) })));
            nextNode = (_jsx("li", Object.assign({}, getButtonRoleAttributes(() => {
                changeActive(active + 1);
            }, active === lastPage), { className: getClassName(`${dPrefix}pagination__button`, {
                    'is-disabled': active === lastPage,
                    [`${dPrefix}pagination__button--border`]: !(dCustomRender && dCustomRender.next),
                }), style: { marginRight: dCompose[dCompose.length - 1] === 'pages' ? 0 : `var(--${dPrefix}pagination-space)` }, title: t('Pagination', 'Next page') }, { children: dCustomRender && dCustomRender.next ? dCustomRender.next : _jsx(RightOutlined, {}) })));
        }
        return [
            prevNode,
            (page) => {
                if (dCustomRender && dCustomRender.page) {
                    return dCustomRender.page(page);
                }
                else {
                    return _jsx("div", { children: page });
                }
            },
            nextNode,
        ];
    })();
    const pageSizeNode = (() => {
        const list = dPageSizeList.map((size) => ({
            label: size.toString(),
            value: size,
        }));
        return (_jsx(DSelect, { className: `${dPrefix}pagination__page-size`, style: { marginRight: dCompose[dCompose.length - 1] === 'page-size' ? 0 : undefined }, dList: list, dModel: pageSize, dCustomItem: (item) => (dCustomRender && dCustomRender.pageSize ? dCustomRender.pageSize(item.value) : item.label), dCustomSelected: (select) => `${select.label}${t('Pagination', ' / Page')}`, onModelChange: (value) => {
                if (!isNull(value)) {
                    changePageSize(value);
                }
            } }, "page-size"));
    })();
    const jumpNode = (() => {
        if (dCompose.includes('jump')) {
            const jumpInput = (_jsx(DInput, { className: `${dPrefix}pagination__jump-input`, dType: "number", dMax: lastPage, dMin: 1, dStep: 1, dModel: jumpValue, dNumbetButton: !dMini, dInputRender: (el) => cloneHTMLElement(el, {
                    onKeyDown: (e) => {
                        var _a, _b;
                        (_b = (_a = el.props).onKeyDown) === null || _b === void 0 ? void 0 : _b.call(_a, e);
                        if (e.code === 'Enter') {
                            e.preventDefault();
                            const val = Number(jumpValue);
                            if (!isNaN(val)) {
                                changeActive(val);
                            }
                        }
                    },
                }), onModelChange: setJumpValue }));
            if (dCustomRender && dCustomRender.jump) {
                return dCustomRender.jump(jumpInput);
            }
            else {
                return (_jsxs(_Fragment, { children: [_jsx("span", { children: t('Pagination', 'Go') }), jumpInput, _jsx("span", { children: t('Pagination', 'Page') })] }));
            }
        }
        return null;
    })();
    return (_jsx("nav", Object.assign({}, restProps, { ref: navRef, className: getClassName(restProps.className, `${dPrefix}pagination`, {
            [`${dPrefix}pagination--mini`]: dMini,
            'is-change': isChange,
        }), role: "navigation", "aria-label": (_b = restProps['aria-label']) !== null && _b !== void 0 ? _b : 'Pagination Navigation' }, { children: dCompose.map((item) => {
            if (item === 'total') {
                return (_jsx("div", Object.assign({ className: `${dPrefix}pagination__total`, style: { marginRight: dCompose[dCompose.length - 1] === 'total' ? 0 : undefined } }, { children: totalNode }), "total"));
            }
            if (item === 'pages') {
                let pages = [];
                if (lastPage <= 7) {
                    pages = Array.from({ length: lastPage }).map((_, index) => index + 1);
                }
                else {
                    for (let n = -3; n <= 3; n++) {
                        pages.push(active + n);
                    }
                    if (pages[0] < 1) {
                        pages = pages.map((n) => n + (1 - pages[0]));
                    }
                    if (pages[6] > lastPage) {
                        pages = pages.map((n) => n - (pages[6] - lastPage));
                    }
                    if (pages[0] > 1) {
                        pages[0] = 1;
                        pages[1] = 'prev5';
                    }
                    if (pages[6] < lastPage) {
                        pages[6] = lastPage;
                        pages[5] = 'next5';
                    }
                }
                return (_jsxs(React.Fragment, { children: [prevNode, pages.map((n) => {
                            if (n === 'prev5') {
                                return (_createElement("li", Object.assign({}, getButtonRoleAttributes(() => {
                                    changeActive(active - 5);
                                }), { key: "prev5", className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--jump5`), title: t('Pagination', '5 pages forward') }),
                                    _jsx(DoubleLeftOutlined, { className: `${dPrefix}pagination__jump5-icon` }),
                                    _jsx("div", Object.assign({ className: `${dPrefix}pagination__ellipsis` }, { children: _jsx(EllipsisOutlined, {}) }))));
                            }
                            else if (n === 'next5') {
                                return (_createElement("li", Object.assign({}, getButtonRoleAttributes(() => {
                                    changeActive(active + 5);
                                }), { key: "next5", className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--jump5`), title: t('Pagination', '5 pages backward') }),
                                    _jsx(DoubleRightOutlined, { className: `${dPrefix}pagination__jump5-icon` }),
                                    _jsx("div", Object.assign({ className: `${dPrefix}pagination__ellipsis` }, { children: _jsx(EllipsisOutlined, {}) }))));
                            }
                            else {
                                return (_jsx("li", Object.assign({ className: getClassName(`${dPrefix}pagination__button`, `${dPrefix}pagination__button--border`, `${dPrefix}pagination__button--number`, {
                                        'is-active': active === n,
                                    }), tabIndex: 0, "data-number": n, onClick: () => {
                                        changeActive(n);
                                    }, onKeyDown: (e) => {
                                        const focusN = (num) => {
                                            if (navRef.current) {
                                                const activeEl = navRef.current.querySelector(`li[data-number="${num}"]`);
                                                activeEl === null || activeEl === void 0 ? void 0 : activeEl.focus({ preventScroll: true });
                                            }
                                            changeActive(num);
                                        };
                                        switch (e.code) {
                                            case 'ArrowLeft':
                                                e.preventDefault();
                                                focusN(n - 1);
                                                break;
                                            case 'ArrowRight':
                                                e.preventDefault();
                                                focusN(n + 1);
                                                break;
                                            case 'Home':
                                                e.preventDefault();
                                                focusN(1);
                                                break;
                                            case 'End':
                                                e.preventDefault();
                                                focusN(lastPage);
                                                break;
                                            default:
                                                break;
                                        }
                                    } }, { children: pageNode(n) }), n));
                            }
                        }), nextNode] }, "pages"));
            }
            if (item === 'page-size') {
                return pageSizeNode;
            }
            if (item === 'jump') {
                return (_jsx("div", Object.assign({ className: `${dPrefix}pagination__jump`, style: { marginRight: dCompose[dCompose.length - 1] === 'jump' ? 0 : undefined } }, { children: jumpNode }), "jump"));
            }
            return null;
        }) })));
}
